@@ -1,12 +1,17 @@
 import traceback
-from utils import JSONConfig, JSONOutput
 import argparse
-
-from optimum import Optimum
-from utils import convert2onnx, upload_outputs, platform_type_infer
-from metadata import platformType, output_prefix
 from pathlib import Path
 
+from .optimum import Optimum
+from .utils import (
+    convert2onnx,
+    upload_outputs,
+    platform_type_infer,
+    JSONConfig,
+    JSONOutput,
+)
+from .metadata import platformType, output_prefix
+
 if __name__ == "__main__":
     parser = argparse.ArgumentParser()
     parser.add_argument(
@@ -31,10 +36,7 @@ if __name__ == "__main__":
     out_json["status"] = 1
     try:
         optimum = Optimum(config["model_name"])
-        optimum.run(
-            onnx_model, 
-            config
-        )
+        optimum.run(onnx_model, config)
     except Exception as e:
         traceback.print_exc()
         out_json["error_info"] = str(e)
